<?php

namespace Moblyze\Site\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Site\Models\Site;

class SitePolicy
{

    /**
     * Determine if the given user can view the site.
     *
     * @param UserPolicy $user
     * @param Site $site
     *
     * @return bool
     */
    public function view(UserPolicy $user, Site $site)
    {
        if ($user->canDo('site.site.view') && $user->isAdmin()) {
            return true;
        }

        return $site->user_id == user_id() && $site->user_type == user_type();
    }

    /**
     * Determine if the given user can create a site.
     *
     * @param UserPolicy $user
     * @param Site $site
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('site.site.create');
    }

    /**
     * Determine if the given user can update the given site.
     *
     * @param UserPolicy $user
     * @param Site $site
     *
     * @return bool
     */
    public function update(UserPolicy $user, Site $site)
    {
        if ($user->canDo('site.site.edit') && $user->isAdmin()) {
            return true;
        }

        return $site->user_id == user_id() && $site->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given site.
     *
     * @param UserPolicy $user
     * @param Site $site
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Site $site)
    {
        return $site->user_id == user_id() && $site->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given site.
     *
     * @param UserPolicy $user
     * @param Site $site
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Site $site)
    {
        if ($user->canDo('site.site.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given site.
     *
     * @param UserPolicy $user
     * @param Site $site
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Site $site)
    {
        if ($user->canDo('site.site.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
